ardt.preprocessors.filters.NK2SignalFilter.NK2SignalFilter
==========================================================

.. currentmodule:: ardt.preprocessors.filters.NK2SignalFilter

.. autoclass:: NK2SignalFilter

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~NK2SignalFilter.__init__
      ~NK2SignalFilter.process_signal
      ~NK2SignalFilter.resolve
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~NK2SignalFilter.context
   
   